#
# spec file for package aws-cli
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aws-cli
Version:        1.27.89
Release:        150200.30.11.1
Summary:        Amazon Web Services Command Line Interface
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/aws/aws-cli
Source0:        https://github.com/aws/%{name}/archive/refs/tags/%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       groff
Provides:       awscli = %{version}
BuildArch:      noarch
%if 0%{?suse_version} && 0%{?suse_version} > 1315
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       python3
Requires:       python3-PyYAML <= 6.0.0
Requires:       python3-PyYAML >= 3.10
Requires:       python3-botocore >= 1.29.89
Requires:       python3-colorama <= 0.5.0
Requires:       python3-colorama >= 0.2.5
Requires:       python3-docutils < 0.20
Requires:       python3-docutils >= 0.10
Requires:       python3-rsa < 5.0.0
Requires:       python3-rsa >= 3.1.2
Requires:       python3-s3transfer < 0.7.0
Requires:       python3-s3transfer >= 0.6.0
Requires:       python3-six
%else
BuildRequires:  bash-completion
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires:       python
Requires:       python-PyYAML <= 5.5
Requires:       python-PyYAML >= 3.10
Requires:       python-botocore >= 1.29.89
Requires:       python-colorama <= 0.5.0
Requires:       python-colorama >= 0.2.5
Requires:       python-docutils >= 0.10
Requires:       python-rsa <= 4.5.0
Requires:       python-rsa >= 3.1.2
Requires:       python-s3transfer < 0.7.0
Requires:       python-s3transfer >= 0.6.0
Requires:       python-six
%endif

%description
The AWS Command Line Interface (CLI) is a unified tool to manage AWS
services. With this tool, multiple AWS services can be controlled
from the command line and automated through scripts.

%prep
%setup -q
sed -i 's/from botocore\.vendored //' awscli/customizations/awslambda.py
sed -i 's/botocore\.vendored\.//' awscli/customizations/configure/__init__.py

%build
%if 0%{?suse_version} && 0%{?suse_version} > 1315
python3 setup.py build
%else
python setup.py build
%endif

%install
%if 0%{?suse_version} && 0%{?suse_version} > 1315
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot} --install-scripts=%{_bindir}
%fdupes %{buildroot}%{python3_sitelib}
find %{buildroot}%{python3_sitelib}/awscli/examples -type f -exec chmod 644 {} \;
%else
python setup.py install --prefix=%{_prefix} --root=%{buildroot} --install-scripts=%{_bindir}
%fdupes %{buildroot}%{python_sitelib}
find %{buildroot}%{python_sitelib}/awscli/examples -type f -exec chmod 644 {} \;
%endif
# No DOS crap
rm %{buildroot}/%{_bindir}/aws.cmd
# Shell completion
install -DTm644 %{buildroot}%{_bindir}/aws_bash_completer %{buildroot}%{_datadir}/bash-completion/completions/aws
install -DTm644 %{buildroot}%{_bindir}/aws_zsh_completer.sh %{buildroot}%{_sysconfdir}/zsh_completion.d/_aws

%files
%defattr(-, root, root)
%doc CHANGELOG.rst README.rst
%license LICENSE.txt
%if 0%{?suse_version} && 0%{?suse_version} > 1315
%dir %{python3_sitelib}/awscli
%dir %{python3_sitelib}/awscli-%{version}-py%{py3_ver}.egg-info
%{python3_sitelib}/awscli/*
%{python3_sitelib}/*egg-info/*
%else
%dir %{python_sitelib}/awscli
%dir %{python_sitelib}/awscli-%{version}-py%{py_ver}.egg-info
%{python_sitelib}/awscli/*
%{python_sitelib}/*egg-info/*
%endif
%{_bindir}/aws
%{_bindir}/aws_completer
%exclude %{_bindir}/aws_bash_completer
%exclude %{_bindir}/aws_zsh_completer.sh
%{_datadir}/bash-completion/completions/aws
%dir %{_sysconfdir}/zsh_completion.d
%config %attr(644,root,root) %{_sysconfdir}/zsh_completion.d/_aws

%changelog
* Wed Apr  5 2023 adrian.glaubitz@suse.com
- Update in SLE-15 (bsc#1209255, jsc#PED-3780)
* Mon Mar 13 2023 adrian.glaubitz@suse.com
- Update to version 1.27.89
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.89/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Feb 24 2023 adrian.glaubitz@suse.com
- Update to version 1.27.78
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.78/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Feb 15 2023 adrian.glaubitz@suse.com
- Update to version 1.27.71
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.71/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Feb  8 2023 adrian.glaubitz@suse.com
- Update to version 1.27.66
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.66/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Feb  3 2023 adrian.glaubitz@suse.com
- Update to version 1.27.60
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.60/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Jan 27 2023 adrian.glaubitz@suse.com
- Update to version 1.27.58
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.58/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Jan 20 2023 adrian.glaubitz@suse.com
- Update to version 1.27.52
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.52/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Jan  3 2023 adrian.glaubitz@suse.com
- Update to version 1.27.41
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.41/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Dec  9 2022 adrian.glaubitz@suse.com
- Update to version 1.27.26
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.26/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Dec  2 2022 adrian.glaubitz@suse.com
- Update to version 1.27.21
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.21/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Nov 14 2022 adrian.glaubitz@suse.com
- Update to version 1.27.8
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.8/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Nov  4 2022 adrian.glaubitz@suse.com
- Update to version 1.27.2
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.2/CHANGELOG.rst
- Relax upper version constraint for python-colorama in
  BuildRequires and Requires to 0.5.0 (bsc#1204917)
- Update Requires in spec file from setup.py
* Thu Nov  3 2022 adrian.glaubitz@suse.com
- Update in SLE-15 (bsc#1204537, jsc#PED-2333)
* Tue Oct 25 2022 adrian.glaubitz@suse.com
- Update to version 1.26.0
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.26.0/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Oct 17 2022 adrian.glaubitz@suse.com
- Update to version 1.25.91
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.91/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Oct  4 2022 adrian.glaubitz@suse.com
- Update to version 1.25.85
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.85/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Sep 20 2022 adrian.glaubitz@suse.com
- Update to version 1.25.76
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.76/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Sep 14 2022 adrian.glaubitz@suse.com
- Update to version 1.25.72
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.72/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Sep  1 2022 adrian.glaubitz@suse.com
- Update to version 1.25.64
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.64/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Aug 26 2022 adrian.glaubitz@suse.com
- Update to version 1.25.60
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.60/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Aug 19 2022 adrian.glaubitz@suse.com
- Update to version 1.25.55
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.55/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Aug  4 2022 adrian.glaubitz@suse.com
- Update to version 1.25.45
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.45/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Jul 26 2022 adrian.glaubitz@suse.com
- Update to version 1.25.37
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.37/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Jun 30 2022 adrian.glaubitz@suse.com
- Update to version 1.25.20
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.20/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Jun  3 2022 adrian.glaubitz@suse.com
- Update to version 1.25.2
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.2/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri May 20 2022 adrian.glaubitz@suse.com
- Update to version 1.24.4 (bsc#1199716)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.24.4/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue May 17 2022 adrian.glaubitz@suse.com
- Update to version 1.24.1
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.24.1/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu May 12 2022 adrian.glaubitz@suse.com
- Update to version 1.23.11
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.23.11/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Apr 27 2022 adrian.glaubitz@suse.com
- Update to version 1.23.1
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.23.1/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Apr  4 2022 adrian.glaubitz@suse.com
- Update to version 1.22.87
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.87/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Mar  2 2022 adrian.glaubitz@suse.com
- Update to version 1.22.65
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.65/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Feb  1 2022 adrian.glaubitz@suse.com
- Update to version 1.22.46
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.46/CHANGELOG.rst
- Add missing python-rpm-macros to BuildRequires
- Update Requires in spec file from setup.py
* Fri Jan 14 2022 adrian.glaubitz@suse.com
- Update to version 1.22.35
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.35/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Jan  6 2022 adrian.glaubitz@suse.com
- Update to version 1.22.28
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.28/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Dec 16 2021 adrian.glaubitz@suse.com
- Update to version 1.22.24
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.24/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Oct 29 2021 adrian.glaubitz@suse.com
- Update to version 1.21.6
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.21.6/CHANGELOG.rst
- Relax upper version dependency for python-docutils in Requires
- Update Requires in spec file from setup.py
* Fri Sep 10 2021 mvyskocil@opensuse.org
- Update to version 1.20.32
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.20.32/CHANGELOG.rst
- Fix rpmlint warnings
  + use defattr for default permissions
  + mark zsh completion file as a config file
- Use github download url as a Source0
- Update Requires in spec file from setup.py
* Wed Jul 28 2021 adrian.glaubitz@suse.com
- Update to version 1.20.7
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.20.7/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Jul 28 2021 adrian.glaubitz@suse.com
- Update to version 1.20.7 (bsc#1189649)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.20.7/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Jul 21 2021 adrian.glaubitz@suse.com
- Update to version 1.19.112
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.112/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Jun 16 2021 adrian.glaubitz@suse.com
- Update to version 1.19.86
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.86/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri May 21 2021 adrian.glaubitz@suse.com
- Update to version 1.19.75
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.75/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Apr 13 2021 adrian.glaubitz@suse.com
- Update to version 1.19.50
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.50/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Feb 18 2021 adrian.glaubitz@suse.com
- Update to version 1.19.9 (bsc#1182421, bsc#1182422, jsc#ECO-3352, jsc#PM-2485)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.9/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Jan 12 2021 adrian.glaubitz@suse.com
- Update to version 1.18.212
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.212/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Nov 30 2020 adrian.glaubitz@suse.com
- Update to version 1.18.185
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.185/CHANGELOG.rst
- Rename README.md to README.rst in %%doc section
- Update Requires in spec file from setup.py
* Fri Oct  9 2020 adrian.glaubitz@suse.com
- Update to version 1.18.156
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.156/CHANGELOG.rst
- Drop patches no longer required
  + hide_py_pckgmgmt.patch
- Update Requires in spec file from setup.py
* Mon Sep  7 2020 adrian.glaubitz@suse.com
- Update to version 1.18.133
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.133/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Wed Aug 12 2020 adrian.glaubitz@suse.com
- Update to version 1.18.117 (bsc#1175147, bsc#1175148, jsc#ECO-2362, jsc#PM-2069)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.117/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
- Rename README.rst to README.md in %%docs section
* Thu Jul 16 2020 adrian.glaubitz@suse.com
- Update to version 1.18.98
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.79/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Mon Jun 15 2020 adrian.glaubitz@suse.com
- Update to version 1.18.79
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.79/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Wed Apr  8 2020 adrian.glaubitz@suse.com
- Update to version 1.18.38 (bsc#1166924, bsc#1168943)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.38/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Apr  7 2020 adrian.glaubitz@suse.com
- Fix build on SLE-12
  + Add bash-completion to BuildRequires for suse_version <= 1315
* Fri Apr  3 2020 adrian.glaubitz@suse.com
- Update to version 1.18.35
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.35/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Mar 24 2020 adrian.glaubitz@suse.com
- Update to version 1.18.27
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.27/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Mon Feb 17 2020 adrian.glaubitz@suse.com
- Update to version 1.18.0
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.0/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Install aws bash completetion script into system path
  + Install aws zsh completion script into /etc/zsh_completion.d
  + Update Requires in spec file from setup.py
* Fri Feb 14 2020 dmueller@suse.com
- make it possible to find the package under the name "awscli"
* Mon Feb 10 2020 rjschwei@suse.com
- Add bash command completion capability (boo#1117074)
* Thu Jan 30 2020 adrian.glaubitz@suse.com
- Update to version 1.17.9
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.17.9/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Dec  5 2019 adrian.glaubitz@suse.com
- Update to version 1.16.297
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.297/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Nov 14 2019 adrian.glaubitz@suse.com
- Update to version 1.16.281
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.281/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Mon Oct 14 2019 adrian.glaubitz@suse.com
- Update to version 1.16.258
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.258/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Fri Sep 27 2019 rjschwei@suse.com
- Add groff as a dependency (boo# 1152258)
* Thu Aug 22 2019 adrian.glaubitz@suse.com
- Update to version 1.16.223 (bsc#1146853)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.223/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Fri Jun 28 2019 adrian.glaubitz@suse.com
- Update to version 1.16.189
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.189/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Jun 20 2019 adrian.glaubitz@suse.com
- Update to version 1.16.182
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.182/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Wed Jun 12 2019 adrian.glaubitz@suse.com
- Update to version 1.16.176
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.176/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
- Relax version constraints for python-PyYAML and python-rsa
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
- Run recursive find with chmod to remove executable bit for
  REST files in example folder to fix rpmlint warning
* Wed Feb 13 2019 adrian.glaubitz@suse.com
- Update to version 1.16.103
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.103/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Jan 24 2019 adrian.glaubitz@suse.com
- Update to version 1.16.94
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.94/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Sun Jan  6 2019 adrian.glaubitz@suse.com
- Update to version 1.16.84
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.84/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Dec  4 2018 adrian.glaubitz@suse.com
- Update to version 1.16.61 (bsc#1118021, bsc#1118024)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.61/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
- Relax version dependency on colorama to <= 0.4.1 (boo#1118099)
* Tue Nov  6 2018 adrian.glaubitz@suse.com
- Update to version 1.16.48
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.48/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Sep 13 2018 adrian.glaubitz@suse.com
- Update to version 1.16.1 (bsc#1105988, bsc#1092493)
  + Fix CVE-2018-15869
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.1/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Replace vendored version of six from botocore with upstream version
  + Update Requires in spec file from setup.py
* Mon Aug 13 2018 adrian.glaubitz@suse.com
- Update to version 1.15.76
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.15.76/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Sun Aug 12 2018 rjschwei@suse.com
- Be less strict with the YAML version requirement
- Switch the license file to %%license
* Sun Jul 22 2018 adrian.glaubitz@suse.com
- Update to version 1.15.63
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.15.63/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Jun 19 2018 adrian.glaubitz@suse.com
- Update to version 1.15.40 (boo#1088310)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.15.40/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Fri Nov 10 2017 jengelh@inai.de
- Do not have description assume any particular user.
* Thu Nov  9 2017 rjschwei@suse.com
- Update to version 1.11.185 (boo#1066528)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.11.185/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
* Tue Sep 12 2017 rjschwei@suse.com
- Update to version 1.11.151
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.11.151/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
- Remove build capability for SLE 11
- Set up for Python 3 build distro > SLE 12 openSUSE Leap 42.x
* Wed Jun 14 2017 rjschwei@suse.com
- Update to version 1.11.104 (bsc#1044370)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.11.104/CHANGELOG.rst
* Thu Dec 15 2016 rjschwei@suse.com
- Update to 1.11.29 (bsc#1015776)
  + forward port hide_py_pckgmgmt.patch
  + feature:batch: Update batch command to latest version
  + feature:logs: Update logs command to latest version
  + feature:rds: Update rds command to latest version
  + feature:dms: Update dms command to latest version
  + feature:marketplacecommerceanalytics: Update marketplacecommerceanalytics
    command to latest version
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
  + feature:sts: Update sts command to latest version
- From 1.11.28
  + feature:cloudfront: Add lambda function associations to cache behaviors.
  + feature:rds: Add cluster create data to DBCluster APIs.
  + bugfix:opsworks: This fixes an issue with opsworks register --local and
    python3 on some versions of linux.
  + feature:waf-regional: With this new feature, customers can use AWS WAF
    directly on Application Load Balancers in a VPC within available regions
    to protect their websites and web services from malicious attacks such
    as SQL injection, Cross Site Scripting, bad bots, etc.
- From 1.11.27
  + feature:config: Update config command to latest version
  + feature:sqs: Update sqs command to latest version
  + feature:s3: Update s3 command to latest version
- From 1.11.26
  + feature:sts: Update sts command to latest version
  + feature:config: Update config command to latest version
  + feature:ec2: Update ec2 command to latest version
  + feature:pinpoint: Update pinpoint command to latest version
- From 1.11.25
  + bugfix:opsworks-cm: Rename opsworkscm to opsworks-cm, keeping support
    for opsworkscm.
- From 1.11.24
  + feature:pinpoint: Update pinpoint command to latest version
  + feature:lambda: Update lambda command to latest version
  + feature:directconnect: Update directconnect command to latest version
  + feature:alias: Add ability to alias commands in the CLI
  + feature:xray: Update xray command to latest version
  + feature:s3: Display transfer speed for s3 commands
  + feature:ssm: Update ssm command to latest version
  + feature:apigateway: Update apigateway command to latest version
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
  + feature:codebuild: Update codebuild command to latest version
  + feature:opsworkscm: Update opsworkscm command to latest version
  + feature:shield: Update shield command to latest version
  + feature:stepfunctions: Update stepfunctions command to latest version
  + feature:appstream: Update appstream command to latest version
  + feature:health: Update health command to latest version
  + feature:ec2: Update ec2 command to latest version
- From 1.11.23
  + feature:polly: Update polly command to latest version
  + feature:snowball: Update snowball command to latest version
  + feature:rekognition: Update rekognition command to latest version
  + feature:lightsail: Update lightsail command to latest version
  + feature:--generate-cli-skeleton output: Add support for generating
    sample output for command
- From 1.11.22
  + feature:s3: Update s3 command to latest version
- From 1.11.21
  + feature:s3: Update s3 command to latest version
  + feature:glacier: Update glacier command to latest version
  + feature:cloudformation: Update cloudformation command to latest version
  + feature:route53: Update route53 command to latest version
- From 1.11.20
  + feature:ecs: Update ecs command to latest version
  + feature:cloudtrail: Update cloudtrail command to latest version
- From 1.11.19
  + feature:cloudformation deploy: Add command to simplify deployments
    of cloudformation stack changes.
  + feature:emr: Update emr command to latest version
  + feature:lambda: Update lambda command to latest version
  + feature:elastictranscoder: Update elastictranscoder command to latest
    version
  + feature:cloudformation package: Add command to package source code for
    cloudfromation template.
  + feature:gamelift: Update gamelift command to latest version
  + feature:application-autoscaling: Update application-autoscaling
    command to latest version
- From 1.11.18
  + bugfix:Powershell: Properly set return code on Powershell.
  + feature:cloudwatch: Update cloudwatch command to latest version
  + feature:sqs: Update sqs command to latest version
  + feature:apigateway: Update apigateway command to latest version
  + feature:meteringmarketplace: Update meteringmarketplace command to
    latest version
- From 1.11.17
  + feature:route53: Update route53 command to latest version
  + feature:servicecatalog: Update servicecatalog command to latest version
- From 1.11.16
  + feature:kinesis: Update kinesis command to latest version
  + feature:ds: Update ds command to latest version
  + feature:elasticache: Update elasticache command to latest version
- From 1.11.15
  + feature:cognito-idp: Update cognito-idp command to latest version
- From 1.11.14
  + feature:cloudformation: Update cloudformation command to latest version
  + feature:logs: Update logs command to latest version
- From 1.11.13
  + feature:directconnect: Update directconnect command to latest version
- From 1.11.12
  + feature:ses: Update ses command to latest version
- From 1.11.11
  + bugfix:cloudtrail: Use STS instead of IAM in CreateSubscription
  + feature:cloudformation: Update cloudformation command to latest version
- From 1.11.10
  + feature:autoscaling: Update autoscaling command to latest version
  + feature:elbv2: Update elbv2 command to latest version
- From 1.11.9
  + feature:ecs: Update ecs command to latest version
  + feature:sms: Update sms command to latest version
- From 1.11.8
  + feature:waf: Update waf command to latest version
  + feature:s3: Port mv to s3transfer.
  + feature:budgets: Update budgets command to latest version
- From 1.11.7
  + feature:cloudfront: Update cloudfront command to latest version
  + feature:iot: Update iot command to latest version
  + feature:config: Update config command to latest version
  + feature:kinesisanalytics: Update kinesisanalytics command to latest version
  + feature:rds: Update rds command to latest version
- From 1.11.6
  + feature:route53: Update route53 command to latest version
  + feature:--region: Add support for us-east-2
- From 1.11.5
  + bugfix:s3 sync --delete: Fix regression where --delete would not delete
    local files
- From 1.11.4
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
  + feature:gamelift: Update gamelift command to latest version
  + feature:s3: Integrate sync command with s3transfer
  + feature:acm: Update acm command to latest version
  + feature:s3: Output progress even when discovering new files to transfer
- From 1.11.3
  + bugfix:Pagination: Fix validation error when providing --no-paginate
    with normalized paging argument.
  + feature:apigateway: Update apigateway command to latest version
  + feature:cloudfront: Update cloudfront command to latest version
  + feature:gamelift: Update gamelift command to latest version
  + feature:rds: Update rds command to latest version
  + feature:codedeploy: Update codedeploy command to latest version
  + feature:sns: Update sns command to latest version
  + feature:kms: Update kms command to latest version
  + feature:elasticache: Update elasticache command to latest version
  + feature:ecr: Update ecr command to latest version
- From 1.11.2
  + feature:s3: Update s3 command to latest version
  + feature:waf: Update waf command to latest version
  + feature:devicefarm: Update devicefarm command to latest version
  + feature:kms: Update kms command to latest version
  + feature:opsworks: Update opsworks command to latest version
  + bugfix:s3: Refactor rb into its own command. In addition, validate that
    no key is supplied regardless of whether or not the force argument is
    supplied.
  + bugfix:route53domains: Rename --end to --end-time to fix a bug relating
    to argparse prefix expansion. Alias --start to --start-time to maintain
    a consistent interface while keeping the old parameter.
  + feature:cognito-idp: Update cognito-idp command to latest version
- From 1.11.1
  + bugfix:s3: Fix regression when downloading empty files.
- From 1.11.0
  + feature:snowball: Update snowball command to latest version
  + feature:s3: Update s3 command to latest version
  + feature:ec2: Update ec2 command to latest version
  + feature:s3: Port cp and rm to s3transfer. Improve progress for those
    commands, showing byte progress.
- Upstream version jump from 1.10.67 to 1.11.0
* Thu Nov 17 2016 dmueller@suse.com
- update to 1.10.67
  * more than 500 changes, have a look at
  https://github.com/aws/aws-cli/compare/1.10.38...1.10.67
* Tue Jun 21 2016 rjschwei@suse.com
- Update to version 1.10.38 (bsc#985858)
  + forward port hide_py_pckgmgmt.patch
  + feature:acm: Update acm command to latest version
  + feature:ses: Update ses command to latest version
  + feature:rds: Update rds command to latest version
  + feature:cloudtrail: Update cloudtrail command to latest version
- From 1.10.37
  + feature:s3: Update s3 command to latest version
- From 1.10.36
  + feature:dynamodbstreams: Update dynamodbstreams command to latest version
  + feature:machinelearning: Update machinelearning command to latest version
  + feature:iot: Update iot command to latest version
  + bugfix:Pagination: Fix regression with --no-paginate introduced in
    [#1958] (fixes #1993)
- From 1.10.35
  + feature:ec2: Update ec2 command to latest version
  + feature:application-autoscaling: Update application-autoscaling
    command to latest version
- From 1.10.34
  + feature:elasticache: Update elasticache command to latest version
- From 1.10.33
  + feature:rds: Update rds command to latest version
  + feature:ec2: Update ec2 command to latest version
  + bugfix:help: Write help content to stdout if less is not installed.
    Fixes #1957
- From 1.10.32
  + feature:firehose: Update firehose command to latest version
  + bugfix:Table: Fix rendering of tables with double-width characters.
  + feature:ec2: Update ec2 command to latest version
  + feature:ecs: Update ecs command to latest version
- From 1.10.31
  + feature:application-autoscaling: Adds support for Application Auto Scaling.
    Application Auto Scaling is a general purpose Auto Scaling service for
    supported elastic AWS resources. With Application Auto Scaling, you can
    automatically scale your AWS resources, with an experience similar to
    that of Auto Scaling.
- From 1.10.29
  + feature:dynamodb: Update dynamodb command to latest version
  + bugfix:Shorthand: Remove back-compat shorthand features from new services.
  + bugfix:Paginator: Print a better error when pagination params are
    supplied along with no-paginate.
  + bugfix:ec2: Sets MaxResults to default value of 1000.
  + feature:workspaces: Update workspaces command to latest version
  + feature:discovery: Update discovery command to latest version
- From 1.10.28
  + feature:ec2: Update ec2 command to latest version
  + feature:ssm: Update ssm command to latest version
  + feature:discovery: Update discovery command to latest version
  + feature:cloudformation: Update cloudformation command to latest version
- From 1.10.27
  + feature:storagegateway: Update storagegateway command to latest version
  + feature:directconnect: Update directconnect command to latest version
  + feature:emr: Update emr command to latest version
  + feature:sqs: Update sqs command to latest version
  + feature:iam: Update iam command to latest version
- From 1.10.26
  + feature:kms: Update kms command to latest version
  + feature:sts: Update sts command to latest version
  + feature:apigateway: Update apigateway command to latest version
  + feature:ecs: Update ecs command to latest version
  + feature:s3: Update s3 command to latest version
  + feature:cloudtrail: Update cloudtrail command to latest version
- From 1.10.25
  + feature:inspector: Update inspector command to latest version
  + feature:codepipeline: Update codepipeline command to latest version
  + bugfix:Configure: Fix issue causing prompts not to display on mintty.
    Fixes #1925
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
- From 1.10.24
  + feature:route53domains: Update route53domains command to latest version
  + feature:opsworks: Update opsworks command to latest version
- From 1.10.23
  + feature:ecr: Update ecr command to latest version
  + feature:acm: Update acm command to latest version
  + feature:ec2: Update ec2 command to latest version
  + feature:sts: Update sts command to latest version
  + feature:cognito-idp: Update cognito-idp command to latest version
- From 1.10.22
  + feature:emr: Add support for smart targeted resize feature
  + feature:iot: Add SQL RulesEngine version support
  + feature:acm: Add tagging support for ACM
- From 1.10.21
  + feature:aws ec2: Add support for two new EBS volume types
  + feature:aws cognito-idp: Add support for new service, aws cognito-idp
  + feature:aws kinesis: Update aws kinesis command to latest version
  + feature:aws elasticbeanstalk: Add support for automatic platform
    version upgrades with managed updates
  + feature:aws devicefarm: Update aws devicefarm command to latest version
  + feature:aws s3: Add support for Amazon S3 Transfer Acceleration
  + feature:aws firehose: Update firehose command to latest version
- From 1.10.20
  + feature:iot: Add commands for managing CA certificates.
  + bugfix:ec2 wait: Fix issues with waiting on incorrect error code.
  + bugfix:s3: Fix issue where multipart uploads were not being properly
    aborted after Cntrl-C. (issue 1905)
* Mon Apr 11 2016 rjschwei@suse.com
- Update to version 1.10.19 (bsc#974993)
  + forward port hide_py_pckgmgmt.patch
  + feature:lambda: Added support for setting the function runtime as
    nodejs4.3, as well as updating function configuration to set the runtime.
  + feature:ds: Added support for Directory Service Conditional Forwarder APIs.
  + feature:elasticbeanstalk: Adds support for three additional elements in
    AWS Elasticbeanstalk's DescribeInstancesHealthResponse: Deployment,
    AvailabilityZone, and InstanceType. Additionally adds support for
    increased EnvironmentName length from 23 to 40.
  + bugfix:Paginator: Allow non-specified input tokens in old starting token
    format.
- From 1.10.18
  + feature:apigateway: Added support for API Import
  + feature:route53: Added support for metric-based health checks and
    regional health checks.
  + feature:sts: Added support for GetCallerIdentity, which returns details
    about the credentials used to make the API call. The details include name
    and account, as well as the type of entity making the call, such as an
    IAM user vs. federated user.
  + feature:s3api: Added support for VersionId in PutObjectAcl (issue 856)
  + bugfix:s3api: Add validation to enforce S3 metadata only contains ASCII.
    (issue 861)
  + bugfix:Exceptions: Consistently parse errors with no body (issue 859)
  + bugfix:Config: Handle case where S3 config key is not a dict (issue 858)
- From 1.10.17
  + feature:acm: Update command to latest version
  + feature:cloudformation: Update command to latest version
  + feature:codedeploy: Update command to latest version
  + feature:dms: Update command to latest version
  + feature:elasticache: Update command to latest version
  + feature:elasticbeanstalk: Update command to latest version
  + feature:redshift: Update command to latest version
  + feature:waf: Update command to latest version
  + bugfix:Pagintor: Fix regression when providing a starting token for a
    paginated command (botocore issue 849)
  + bugfix:Response Parsing: Handle case when generic HTML error response
    is received (botocore issue 850)
  + bugfix:Request serialization: Handle case when non str values are
    provided for header values when using signature version 4
    (botocore issue 852)
  + bugfix:Retry: Retry HTTP responses with status code 502
    (botocore issue 853)
  + bugfix:ec2 run-instances: Fix issue when providing
  - -secondary-private-ip-address-count argument (issue 1874)
- From 1.10.16
  + feature:elasticache: Update command to latest version
  + feature:rds: Update command to latest version
  + feature:storagegateway: Update command to latest version
- from 1.10.15
  + feature:aws devicefarm: Add support to pay a flat monthly fee for
    unlimited testing of your Android and iOS apps with AWS Device Farm
    device slots
  + feature:aws rds: Add support for customizing the order in which Aurora
    Replicas are promoted to primary instance during a failover
- From 1.10.14
  + feature:meteringmarketplace: The AWS Marketplace Metering Service
    enables sellers to price their products along new pricing dimensions.
    After a integrating their product with the AWS Marketplace Metering
    Service, that product will emit an hourly record capturing the usage of
    any single pricing dimension. Buyers can easily subscribe to software
    priced by this new dimension on the AWS Marketplace website and only
    pay for what they use.
  + feature:s3api: Added support for delete marker and abort multipart
    upload lifecycle configuration.
  + feature:iot: Added support for Amazon Elasticsearch Service and
    Amazon Cloudwatch actions for the AWS IoT rules engine.
  + feature:cloudhsm: Added support for tagging resources.
- From 1.10.13
  + feature:DMS: Added support for AWS Database Migration Service
  + feature:SES: Added support for white-labeling
  + feature:CodeDeploy: Added support for BatchGetDeploymentGroups
  + feature:endpoints: Updated endpoints to latest version
  + bugfix:groff: Fix groff command which was causing issues on some systems
  + bugfix:shorthand: Allow # in keys in the shorthand parser
- From 1.10.12
  + feature:gamelift: Update command to latest version
  + feature:iam: Update command to latest version
  + feature:redshift: Update command to latest version
- From 1.10.11
  + feature:acm: Update acm command to latest version
  + feature:codecommit: Update codecommit model to latest version
  + feature:config: Update config command to latest version
  + feature:devicefarm: Update devicefarm command to latest version
  + feature:directconnect: Update directconnect command to latest version
  + feature:events: Update events command to latest version
  + bugfix:aws s3 cp: Add error checking when attempting recursive copies
    or syncs with streaming output (issue 1771)
- From 1.10.10
  + feature:aws ec2: Add support for VPC peering with security groups.
  + feature:aws ds: Add support for SNS event notifications.
  + bugfix:aws s3 rb: Fix issue where bucket is still attempted to be
    removed when the preceding delete requests failed. (issue 1827)
  + bugfix:aws storagegateway: Fix issue in aliasing required args.
    (issue 1790)
- From 1.10.9
  + bugfix:aws s3: Avoid MD5 checksumming if unavailable. (issue 1812)
  + feature:aws dynamodb: Add support for describing limits.
  + feature:aws apigateway: Add support for testing invoke authorizers
    and flushing stage authorizers cache.
  + feature:aws cloudsearchdomain: Add support for new stat fields.
- From 1.10.8
  + bugfix:aws s3: Disable use of MD5 when SHA256 checksum is already
    calculated for the body (botocore issue 804)
  + bugfix:FIPS: Handle case where MD5 cipher is not available on FIPS
    compliant systems (botocore issue 807)
  + feature:aws cloudformation: Update AWS CloudFormation command to the
    latest version
  + feature:aws logs: Update Amazon CloudWatch Logs command to the latest
    version
  + feature:aws ses: Update Amazon SES to the latest version
  + feature:aws autoscaling: Update Auto Scaling to the latest version
- From 1.10.7
  + bug:aws configure set: Fix issue when adding entries to an empty
    profile section (issue 1806)
  + feature:aws route53: Add suport for SNI health checks
- From 1.10.6
  + feature:aws storagegateway: Added support for user-supplied barcodes.
  + feature:aws codedeploy: Added support for setting up triggers for a
    deployment group.
  + bugfix:aws emr: Fix missing dns name issue with private clusters.
    (issue 1749)
  + bugfix:aws emr: Fix issue where impala args were not joined with commas.
    (issue 1802)
- From 1.10.5
  + feature:aws rds: Added support for Cross-account Encrypted (KMS) snapshot
    sharing.
  + feature:aws emr: Added support for adding EBS storage to EMR instances.
  + bugfix:pagination: Fixed a bug that was causing non-string service
    tokens to fail on serialization
- From 1.10.4
  + feature:aws lambda: Add support for accessing resources in your VPC.
  + feature:aws apigateway: Add support for custom request authorizers.
- From 1.10.3
  + feature:aws cloudfront: Add support for new ACMCertificateARN parameter
  + feature:aws marketplacecommerceanalytics generate-data-set: Add support
    for --customer-defined-values parameter
- From 1.10.2
  + feature:aws gamelift: Add support for AWS GameLift
  + bugfix:Assume Role: Fix issue where temporary credentials from assuming
    a role were not being properly cached (issue 1684)
- From 1.10.1
  + feature:aws waf: Add support for blocking, allowing, or monitoring
    (count) requests based on the content in HTTP request bodies.
  + bugfix:aws ssm: Remove constraint on Amazon EC2 instance id's.
    (issue 1729)
- From 1.10.0
  + feature:aws acm: adds support for AWS Certificate Manager
  + feature:aws cloudfront: adds support for AWS Certificate Manager
    certificates
  + feature:aws cloudfront create-distribution: Adds support for
  - -origin-domain-name and --default-root-object
  + feature:aws cloudfront update-distribution: Adds support for
  - -default-root-object
  + feature:aws iot: adds support for topic rules
  + feature:aws cloudformation: adds suport for ContinueUpdateRollback
- From 1.9.21
  + feature:aws sts: now returns RegionDisabledException instead of
    AccessDenied when a user sends an API request to an STS regional
    endpoint that is not activated for that AWS account. This enables
    customers to more easily decide how to respond, such as by trying to
    call a different region instead of simply failing the call.
  + feature:aws opsworks: adds support for new enums.
  + feature:aws devicefarm: adds support running Appium tests written in
    Python against your native, hybrid and browser-based apps on AWS Device
    Farm.
- From 1.9.20
  + bugfix:aws cloudfront: Fix regression in waiters.
- From 1.9.19
  + feature:aws events: Initial support for Amazon CloudWatch Events.
    CloudWatch Events allows you to track changes to your AWS resources
    with less overhead and greater efficiency.
  + feature:aws ec2: Adds support for purchasing reserved capacity for
    specific blocks of time on a one-time of recurring basis.
  + feature:aws cloudfront: Adds support for HTTPS-only connections, and
    control of edge-to-origin request headers.
  + bugfix:aws s3: Gracefully handle encoding errors when printing S3
    keys (issue 1719)
- From 1.9.18
  + feature:aws ec2: Enables support for DNS resolution of public hostnames
    to private IP addresses when queried over ClassicLink. Additionally, you
    can now access private hosted zones associated with your VPC from a
    linked EC2-Classic instance. ClassicLink DNS support makes it easier
    for EC2-Classic instances to communicate with VPC resources using public
    DNS hostnames.
  + feature:aws ec2: Add support for the new 63-bit EC2 Instance and
    Reservation IDs.
- From 1.9.17
  + bugfix:aws ssm: Documentation update.
- From 1.9.16
  + feature:aws ec2: Add new EC2 instance type: t2.nano
  + feature:aws datapipeline list-runs: Add support for output format
- From 1.9.15
  + feature:aws ecr: Add aws ecr commands
  + feature:aws emr: Update aws emr create-cluster to accept Amazon EC2
    security group
  + feature:aws ecs: Update ecs command to include a new deployment option
- From 1.9.14
  + feature:aws rds: Adds Enhanced Monitoring support so that you can
    monitor operating system metrics for your RDS DB instances
  + feature:aws configservice: Support for IAM resource types
  + feature:aws cloudtrail: Adds isMultiRegion to some of the commands
  + feature:aws cloudfront: Adds support for gzip
  + feature:aws ec2: Adds new commands for VPC Managed NAT
- From 1.9.13
  + feature:aws ec2 copy-image: Adds two optional parameters to support
    launching EC2 instances with EBS encrypted boot volumes.
  + bugfix:aws: Fix regression when using AWS_DATA_PATH environment
    variable (issue 736)
* Thu Dec 10 2015 rjschwei@suse.com
- Update to version 1.9.12 (bsc#958686)
  + feature:aws configure add-model: Added command for updating commands
    in the CLI and clients in boto3. (issue 1664)
  + feature:aws cloudfront create-invalidation: Add a new --paths option.
    (issue 1662)
  + feature:aws cloudfront sign: Add a new command to create a signed url.
    (issue 1668)
  + feature:aws autoscaling: Added support for protecting instances from
    scale-in events.
  + feature:aws rds: Added support for Aurora encryption at rest.
- From version 1.9.11
  + feature:aws rds: Added support for specifying port number.
  + feature:aws ds: Added support for Microsoft ActiveDirctory.
  + feature:aws route53: Added support for TrafficFlow, a new management
    and modeling layer for Route53.
  + feature:Timeouts: Added additonal options for configuring socket timeouts.
- From version 1.9.10
  + feature:aws config: Added support for dedicated hosts.
  + feature:aws s3: Added support for custom metadata in cp, mv, and sync.
- From version 1.9.9
  + feature:aws s3api: Added support for the aws-exec-read canned ACL on
    objects.
  + feature:aws elasticbeanstalk: Added support for composable web applications.
  + feature:aws ec2: Added support for EC2 dedicated hosts.
  + feature:aws ecs: Added support for task stopped reasons and task start
    and stop times.
- From version 1.9.8
  + feature:Read Timeouts: Add --cli-read-timeout to specify the number of
    seconds until a read times out.
  + bugfix:aws s3: Fix regression when downloading a restored Glacier object
    (issue 1650 <https://github.com/aws/aws-cli/pull/1650>__)
  + bugfix:aws s3: Fix issue when encountering "out of disk space" errors as
    well as permissions errors when downloading large files (issue 1645,
    issue 1442)
  + bugfix:aws opsworks register: Support --no-verify-ssl argument for the
    aws opsworks register command (issue 1632)
  + feature:s3: Add support for Server-Side Encryption with KMS and
    Server-Side Encryption with Customer-Provided Keys. (issue 1623)
- From version 1.9.7
  + feature:aws rds: Cross account snapshot sharing and Modify DB Instance
    Visibility features
  + bugfix:memory management: Resolve a potential memory leak when creating
    lots of clients on Python 2.6 and Linux 2.6
  + bugfix:presign url: Now generate_presigned_url() works correctly with
    different expiry time
- From version 1.9.6
  + bugfix:shorthand: Allow . as a valid key character. (issue 1628)
  + feature:aws apigateway: Support for stage variables to configure
    the different deployment stages
- From version 1.9.5
  + bugfix:aws help: Gracefully handle Ctrl-C interrupts. (issue 1619)
  + bugfix:aws datapipeline create-default-roles: Fix issue with error
    handling. (issue 1618)
  + bugfix:aws s3: Skip glacier objects when downloading from S3. (issue 1581)
  + feature:aws s3api: Auto-populate --copy-source-sse-customer-key-md5
    (botocore issue 709)
- From version 1.9.4
  + feature:aws datapipeline create-default-roles: Creates default IAM
    roles for creating EMR clusters. (issue 1616)
  + feature:aws devicefarm: Add commands for updating and deleting projects,
    device pools, uploads, and runs.
- From version 1.9.3
  + feature:aws iam: Add support for resource-level policy simulation
- From version 1.9.2
  + bugfix:aws s3: Fix some local path validation issues (issue 1575)
  + bugfix:aws storagegateway: Fix --tape-ar-ns, --volume-ar-ns, and
  - -vtl-device-ar-ns to --tape-arns, --volume-arns, and --vtl-device-arns,
    respectively. The old arguments are still supported for backwards
    compatibility, but are no longer documented. (issue 1599)
  + bugfix:aws configservice subscribe: Fix an issue when creating a new
    S3 bucket (issue 1593)
  + bugfix:aws apigateway put-integration: Fix issue with --uri and
  - -integration-http-method parameters (issue 1605)
- From version 1.9.1
  + feature:aws ssm: Add support for Amazon EC2 Run Command
  + feature:aws apigateway: Add support for Amazon API Gateway
- From version 1.9.0
  + feature:aws iam: Add policy simulator support
  + feature:aws autoscaling: Add support for launch configurations
    that include encrypted Amazon Elastic Block Store (EBS) volumes
  + feature:configure: Add support for ca_bundle config variable
  + feature:Assume Role: Add role_session_name config variable to control
    the RoleSessionName when assuming roles (issue 1389)
  + bug:Argument Parsing: Handle case when empty list parameter was
    specified with no value (issue 838)
- From version 1.8.13
  + feature:aws deploy: Compress zip files when using aws deploy push
    (issue 1534 <https://github.com/aws/aws-cli/pull/1534>--)
  + bugfix:Shorthand Parser: Fix issue when display error message for
    multiline shorthand syntax values (issue 1543)
  + bugfix:aws route53: Automatically retry Throttling and
    PriorRequestNotComplete errors (botocore issue 682)
  + feature:aws s3/s3api: Add support for changing the bucket addressing
    style (botocore issue 673)
  + bugfix:aws s3api: Add missing --server-side-encryption option to
    upload-part command
  + feature:aws kms: Add ability to delete customer master keys (CMKs)
* Sat Oct 10 2015 rjschwei@suse.com
- Update to version 1.8.12 (bsc#949877)
  + feature:aws iot: Add support for AWS IoT
  + feature:aws iot-data: Add support for AWS IoT Data Plane
  + feature:aws lambda: Add support for aliasing and function versioning
  + feature:aws ecs: Update commands
  + feature:aws marketplacecommerceanalytics: Add support for AWS
    Marketplace Commerce Analytics
  + feature:aws firehose: Add support for Amazon Kinesis Firehose
  + feature:aws inspector: Add support for Amazon Inspector
  + feature:aws kinesis: Add support for updating stream retention periods
  + feature:aws configservice: Add support for config rules
  + feature:aws waf: Add support for AWS WAF
  + feature:aws ec2: Add support for spot blocks
  + feature:aws cloudfront: Add support for adding Web ACLs to CloudFront
    distributions
  + feature:aws es: Adds support for the new Amazon Elasticsearch
  + feature:aws cloudtrail: Adds support for log file integrity validation,
    log encryption with AWS KMS-Managed Keys (SSE-KMS), and trail tagging.
  + feature:aws rds create-db-instance: --db-instance-class has a new value
    as db.t2.large
  + feature:aws workspaces: Adds support for volume encryption in Amazon
    WorkSpaces.
  + feature:aws ses: Adds 17 new operations for accepting incoming emails.
  + feature:aws cloudformation describe-account-limits: This is a new API.
  + feature:aws ec2 modify-spot-fleet-request: This is a new API.
  + bugfix:aws elasticbeanstalk: Documentation update.
  + feature:aws cognito-sync: Update API to latest version
  + feature:aws cognito-identity: Update API to latest version
  + bugfix:Assume Role Provider: Fix issue where profile does not exist
    errors were not being propogated back to the user (issue 1515)
  + bugfix:Shorthand Syntax: Fix parser regression when a key name has an
    underscore character (issue 1510)
  + feature:aws s3: Add support for STANDARD_IA storage class to the aws s3
    commands (issue 1511)
  + feature:aws logs: Add support for create-export-task, cancel-export-task,
    and describe-export-tasks.
  + bugfix:Output: Only omit printing response to stdout if the response is
    an empty dictionary (issue 1496)
  + feature:aws s3/s3api: Update Amazon S3 commands to the latest version
  + feature:aws ec2 request-spot-fleet: Add new Diversified bidding strategy
    parameter
  + feature:aws ec2 describe-snapshots: Add new dataEncryptionKeyId and
    StateMessage parameters
  + feature:aws efs describe-mount-targets: Add new optional MountTargetId
    parameter
  + feature:aws route53: Add calculated health checks and latency health checks
  + bugfix:StreamingBody: File-like object for HTTP response can now be
    properly closed
  + feature:aws iam: Add two new APIs that enable programmatic access to
    the IAM policy simulator
  + feature:aws importexport: Documentation update
  + bugfix:aws machinelearning: Remove a constraint
  + feature:aws kinesis get-records: Add a timestamp field to all Records
  + bugfix:aws cloudfront: Add paginators and waiters
  + feature:aws storagegateway: Add support for resource tagging.
  + feature:aws ec2 request-spot-fleet: Add support for new request config
    parameters
  + bugfix:Shorthand Parser: Fix regression where '-' character was not
    accepted as a key name in a shorthand value (issue 1470)
  + bugfix:Shorthand Parser: Fix regression where spaces in unquoted
    values were not being accepted (issue 1471)
  + feature:aws configservice: Add support for listing discovered resources
  + bugfix:aws emr create-default-roles: Fix the issue where the command
    would fail to honor an existing AWS_CA_BUNDLE environment setting and
    end up with "SSLError: object has no attribute" (issue 1468)
  + feature:Shorthand Syntax: Add support for nested hashes when using
    shorthand syntax (issue 1444)
  + feature:aws codepipeline: Add support for specification of an encryption
    key to use with the artifact bucket, when creating and updating a pipeline
  + feature:aws s3: Add support for event notification filters
  + bugfix:aws iam create-virtual-mfa-device: Fix issue when an error
    response is received from the create-virtual-mfa-device command (issue 1447)
  + feature:aws elasticbeanstalk: Add support for enhanced health reporting
    in aws elasticbeanstalk commands
  + feature:Shared Credentials File: Add support for changing the shared
    credentials file from the default location of ~/.aws/credentials
    by setting the AWS_SHARED_CREDENTIALS_FILE environment variable
    (botocore issue 623)
  + feature:Waiters: Add aws iam wait instance-profile-exists and aws
    iam wait user-exists commands (botocore issue)
  + feature:aws swf: Add support for Added support for invoking AWS
    Lambda tasks from an Amazon SWF workflow.
  + feature:aws devicefarm: Add support for testing iOS applications
    with AWS Device Farm.
* Fri Jul 31 2015 ms@suse.com
- update to version 1.7.42 (fate#318337)
  - feature:``aws opsworks``: Add support for managing Amazon ECS
  - feature:``aws rds``: Add support for Amazon Aurora
  - feature:``aws s3api``: Add support for more types of event notifications.
  - feature:``aws s3api``: Add support for GET/HEAD storage class response
  - feature:``aws logs``: Add destination API support.
  - feature:``aws glacier``: Add support for Vault Lock.
  - feature:``aws emr``: Add support for release-based clusters.
  - feature:``aws ecs``: Update API
* Mon Jun  1 2015 rjschwei@suse.com
- update to version 1.7.31 (bnc#905354)
  - Follow up to previous update to address API compatibility issues
    with botocore
  - Improved lambda support
  - Add support for uploading code using Amazon S3
  - Preview services are now documented
    and will also show up in the list of available services
  + From 1.7.30
  - Add support for ``aws efs``
  - Add paginators and waiters for ``aws ecs``
* Tue May 26 2015 rjschwei@suse.com
- update to version 1.7.29 (bnc#905354)
  + Follow up to previous update to address compatibility with latest
    amazon-ecs-agent
  + From 1.7.28
  - feature:aws ec2: Add support for Spot Fleet.
  - feature:aws opsworks: Add support for custom AutoScaling.
  - feature:aws elasticbeanstalk: Update model to latest version.
  + From 1.7.27
  - feature:aws ds: Add support for AWS Directory Service.
  - feature:aws ec2: Add support for VPC endpoints for Amazon S3.
  - feature:aws ec2: Add support for EIP Migration.
  - feature:aws logs: Add support for filtering log events.
  + From 1.7.26
  - feature:aws glacier: Add support for vault policies.
  - bugfix:aws iam create-open-id-connect-provider: Fix issue where the
  - -url parameter would try to retrieve the contents from the url instead
    of use the url as its value. (issue 1317)
  - bugfix:aws workspaces: Fix issue where throttling errors were not
    being retried (botocore issue 529)
  + From 1.7.25
  - feature:aws dynamodb query: Add support for KeyConditonExpression.
  + From 1.7.24
  - feature:aws help topics: Add support for listing available help topics.
  - feature:aws help config-vars: Add help topic for configuration variables.
  - feature:aws help return-codes: Add help topic for return codes.
  - feature:aws help s3-config: Add help topic for configuration of s3
    commands.
  - bugfix:aws lambda create-function/update-function-code: Improve
    error message when invalid --zip-file values are provided (issue 1296)
  - feature:aws ec2: Add support for new VM Import APIs, including
    import-image. The new APIs provide support for importing multi-volume
    VMs to Amazon EC2 and other enhancements.
  - feature:aws iam: Update AWS IAM command to latest version
  + From 1.7.23
  - feature:aws cognito-sync: Add support for Amazon Cognito Events.
  - bugfix:Parsing: Treat empty XML nodes in a response as an empty
    string instead of None if the underlying structure member is a string.
    This fixes the broken password-data-available Amazon EC2 waiter. Note:
    this changes the output of the CLI and may affect filtering with the
  - -query parameter. (issue 1252, botocore issue 506)
  + From 1.7.22
  - bugfix:aws ecs: Minor documentation fixes.
  + From 1.7.21
  - feature:aws workspaces: Add support for Amazon WorkSpaces.
  - feature:aws machinelearning: Add support for Amazon Machine Learning.
  - feature:aws s3api: Add support for specifying Lambda bucket
    notifications without needing to specify an invocation role.
  - feature:aws lambda: Update to latest api.
  - feature:aws ecs: Add support for Amazon ECS Service scheduler.
  + From 1.7.20
  - feature:aws datapipeline: Add support for deactivating pipelines.
  - feature:aws elasticbeanstalk: Add support for cancelling in-progress
    environment updates or application version deployment.
  + From 1.7.19
  - feature:aws codedeploy: Add register, deregister, install, and
    uninstall commands and update to the latest AWS CodeDeploy API.
  - feature:aws rds: Add support for describe-certificates.
  - feature:aws elastictranscoder: Add support for PlayReady DRM.
  - feature:aws ec2: Add support for D2 instances.
  + From 1.7.18
  - bugfix:Pagination: Fix issue where disabling pagination did not work
    when shadowing arguments. Affects commands such as aws route53
    list-resource-record-sets.
  - feature:aws elastictranscoder: Add support for job timing and
    input/output metadata
  - feature:aws iam: Add NamedPolicy to GetAccountAuthorization details
  - feature:aws opsworks: Allow for BlockDeviceMapping on EC2 instances
    launched through OpsWorks
  + From 1.7.17
  - feature:aws emr: Adds support for Amazon S3 client-side encryption
    in Amazon EMR and setting configuration values for several variables
    in the create-cluster and ssh commands. Also, the create-default-roles
    command will now auto-populate the Service Role and Instance Profile
    variables in the configuration file with the default roles after they
    are created.
  + From 1.7.16
  - feature:aws ec2 wait image-available: Add support for polling until
    an EC2 image is available (issue 1105)
  - feature:aws ec2 wait: Add support for additional EC2 waiters including
    instance-status-ok, password-data-available,
    spot-instance-request-fulfilled, and system-status-ok
  - feature:aws s3api: Add support for Amazon S3 cross region replication
  - feature:aws s3api: Add support for Amazon S3 requester pays (issue 797)
  - bugfix:Tab Completion: Fix issue where tab completion could not handle
    an LC_CTYPE of UTF-8 (issue 1233)
  - bugfix:aws s3api put-bucket-notification: Fix issue where an empty
    notification configuration could not be specified (botocore issue 495)
  - bugfix:aws cloudfront: Fix issue when calling cloudfront commands
    (issue 1234)
  - bugfix:aws ec2 copy-snapshot: Fix issue with the aws ec2 copy-snapshot
    command not correctly generating the presigned url argument
    (botocore issue 498)
  + From 1.7.15
  - feature:aws elastictranscoder: Add support for Applied Color
    SpaceConversion.
  - bugfix:aws --profile: Fix issue where explicitly specifying profile
    did not override credential environment variables. (botocore issue 486)
  - bugfix:aws datapipeline list-runs: Fix issue with --schedule-interval
    parameter. (issue 1225)
  - bugfix:aws configservice subscribe: Fix issue where users could not
    subscribe to a s3 bucket that they had no HeadBucket permissions to.
    (issue 1223)
  - bugfix:aws cloudtrail create-subscription: Fix issue where command
    would try to fetch the contents at a url using the contents of the
    custom policy as the url. (issue 1216)
  + From 1.7.14
  - feature:aws logs: Update aws logs command to the latest model.
  - feature:aws ec2: Add paginators for the describe-snapshots sub-command.
  - feature:aws cloudtrail: Add support for the new lookup-events
    sub-command.
  - bugfix:aws configure set: Fix issue when setting nested configuration
    values
  - feature:aws s3: Add support for --metadata-directive that allows
    metadata to be copied or replaced for single part copies. (issue 1188)
  + From 1.7.13
  - feature:aws cloudsearch: Update aws cloudsearch command to the latest
    model
  - feature:aws cognito-sync: Update aws cognito-sync command to allow
    customers to receive near-realtime updates as their data changes as
    well as exporting historical data. Customers configure an Amazon
    Kinesis stream to receive the data which can then be processed and
    exported to other data stores such as Amazon Redshift.
  - bugfix:aws opsworks: Fix issue with platform detection on linux
    systems with python3.3 and higher (issue 1199)
  - feature:Help Paging: Support paging through more when running help
    commands on windows (issue 1195)
  - bugfix:aws s3: Fix issue where read timeouts were not retried.
    (issue 1191)
  - feature:aws cloudtrail: Add support for regionalized policy templates
    for the create-subscription and update-subscription commands.
    (issue 1167)
  - bugfix:parsing: Fix issue where if there is a square bracket inside
    one of the values of a list, the end character would get removed.
    (issue 1183)
  + From 1.7.12
  - feature:aws datapipeline: Add support for tagging.
  - feature:aws route53: Add support for listing hosted zones by name
    and getting the hosted zone count.
  - bugfix:aws s3 sync: Remove --recursive parameter. The sync command is
    always a recursive operation meaning the inclusion or exclusion of
  - -recursive had no effect on the sync command. (issue 1171)
  - bugfix:aws s3: Fix issue where --endpoint-url was being ignored
    (issue 1142)
  + From 1.7.11
  - bugfix:aws sts: Allow calling assume-role-with-saml without credentials.
  - bugfix:aws sts: Allow users to make regionalized STS calls by
    specifying the STS endpoint with --endpoint-url and the region with
  - -region. (botocore issue 464)
  + From 1.7.10
  - bugfix:aws sts: Fix regression where if a region was not activated
    for STS it would raise an error if call was made to that region.
  + From 1.7.9
  - feature:aws cloudfront: Update to latest API
  - feature:aws sts: Add support for STS regionalized calls
  - feature:aws ssm: Add support for Amazon Simple Systems Management
    Service (SSM)
  + From 1.7.8
  - bugfix:aws s3: Fix auth errors when uploading large files to the
    eu-central-1 and cn-north-1 regions (botocore issue 462)
  + From 1.7.7
  - bugfix:aws ec2 revoke-security-group-ingress: Fix parsing of a
  - -port value of ICMP echo request (issue 1075)
  - feature:aws iam: Add support for managed policies
  - feature:aws elasticache: Add support for tagging
  - feature:aws route53domains: Add support for tagging of domains
  + From 1.7.6
  - feature:aws dynamodb: Add support for index scan
  - bugfix:aws s3: Fix issue where literal value for --website-redirect
    was not being used. (issue 1137)
  - bugfix:aws sqs purge-queue: Fix issue with the processing of the
  - -queue-url parameter (issue 1126)
  - feature:aws s3: Add support for config variable for changing S3 runtime
    values (issue 1122)
  - bugfix:Proxies: Fix issue with SSL certificate validation when using
    proxies and python 2.7.9 (botocore issue 451)
  + From 1.7.5
  - bugfix:aws datapipeline list-runs: Fix issue where --status values
    where not being serialized correctly (issue 1110)
  - bugfix:Output Formatting: Handle broken pipe errors when piping the
    output to another program (issue 1113)
  - bugfix:HTTP Proxy: Fix issue where aws s3/s3api commands would hang
    when using an HTTP proxy (issue 1116)
  - feature:aws elasticache wait: Add waiters for the aws elasticache
    wait (botocore issue 443)
  - bugfix:Locale Settings: Fix issue when Mac OS X has an LC_CTYPE value
    of UTF-8 (issue 945)
  + From 1.7.4
  - feature:aws dynamodb: Add support for online indexing.
  - feature:aws importexport get-shipping-label: Add support for
    get-shipping-label.
  - feature:aws s3 ls: Add --human-readable and --summarize options
    (issue 1103)
  - bugfix:aws kinesis put-records: Fix issue with base64 encoding for
    blob types (botocore issue 413)
  + From 1.7.3
  - feature:aws emr: Add support for security groups.
  - feature:aws cognitio-identity: Enhance authentication flow by beingi
    able to save associations of IAM roles with identity pools.
  + From 1.7.2
  - feature:aws autoscaling: Add ClassicLink support.
  - bugfix:aws s3: Fix issue where mtime was set before file was finished
    downloading. (issue 1102)
* Sun Jan 18 2015 rschweikert@suse.com
- Update to version 1.7.1 (bnc#905354)
  + bugfix:``aws s3 cp``: Fix issue with parts of a file being
    downloaded more than once when streaming to stdout
    (`issue 1087 <https://github.com/aws/aws-cli/pull/1087>`__)
  + bugfix:``--no-sign-request``: Fix issue where requests were still trying to
    be signed even though user used the ``--no-sign-request`` flag.
    (`botocore issue 433 <https://github.com/boto/botocore/pull/433>`__)
  + bugfix:``aws cloudsearchdomain search``: Fix invalid signatures when
    using the ``aws cloudsearchdomain search`` command
    (`issue 976 <https://github.com/aws/aws-cli/issues/976>`__)
  + feature:``aws cloudhsm``: Add support for AWS CloudHSM.
  + feature:``aws ecs``: Add support for ``aws ecs``, the Amazon EC2
    Container Service (ECS)
  + feature:``aws rds``: Add Encryption at Rest and CloudHSM Support.
  + feature:``aws ec2``: Add Classic Link support
  + feature:``aws cloudsearch``: Update ``aws cloudsearch`` command
    to latest version
  + bugfix:``aws cloudfront wait``: Fix issue where wait commands did not
    stop waiting when a success state was reached.
    (`botocore issue 426 <https://github.com/boto/botocore/pull/426>`_)
  + bugfix:``aws ec2 run-instances``: Allow binary files to be passed to
    ``--user-data``
    (`botocore issue 416 <https://github.com/boto/botocore/pull/416>`_)
  + bugfix:``aws cloudsearchdomain suggest``: Add ``--suggest-query``
    option to fix the argument being shadowed by the top level
    ``--query`` option.
    (`issue 1068 <https://github.com/aws/aws-cli/pull/1068>`__)
  + bugfix:``aws emr``: Fix issue with endpoints for ``eu-central-1`` and
    ``cn-north-1``
    (`botocore issue 423 <https://github.com/boto/botocore/pull/423>`__)
  + bugfix:``aws s3``: Fix issue where empty XML nodes are now parsed
    as an empty string ``""`` instead of ``null``, which allows for
    round tripping ``aws s3 get/put-bucket-lifecycle``
    (`issue 1076 <https://github.com/aws/aws-cli/issues/1076>`__)
  + bugfix:AssumeRole: Fix issue with cache filenames when assuming a role
    on Windows
    (`issue 1063 <https://github.com/aws/aws-cli/issues/1063>`__)
  + bugfix:``aws s3 ls``: Fix issue when listing Amazon S3 objects containing
    non-ascii characters in eu-central-1
    (`issue 1046 <https://github.com/aws/aws-cli/issues/1046>`__)
  + feature:``aws storagegateway``: Update the ``aws storagegateway`` command
    to the latest version
  + feature:``aws emr``: Update the ``aws emr`` command to the latest
    version
  + bugfix:``aws emr create-cluster``: Fix script runnner jar to the current
    region location when ``--enable-debugging`` is specified in the
    ``aws emr create-cluster`` command
  + bugfix:``aws datapipeline get-pipeline-definition``: Rename operation
    parameter ``--version`` to ``--pipeline-version`` to avoid shadowing
    a built in parameter
    (`issue 1058 <https://github.com/aws/aws-cli/pull/1058>`__)
  + bugfix:pip installation: Fix issue where pip installations would cause
    an error due to the system's python configuration
    (`issue 1051 <https://github.com/aws/aws-cli/issues/1051>`__)
  + feature:``aws elastictranscoder``: Update the ``aws elastictranscoder``
    command to the latest version
  + bugfix:Non-ascii chars: Fix issue where escape sequences were being printed
    instead of the non-ascii chars
    (`issue 1048 <https://github.com/aws/aws-cli/issues/1048>`__)
  + bugfix:``aws iam create-virtual-mfa-device``:  Fix issue with ``--outfile``
    not supporting relative paths
    (`issue 1002 <https://github.com/aws/aws-cli/pull/1002>`__)
  + feature:``aws sqs``: Add support for Amazon Simple Queue Service purge queue
    which allows users to delete the messages in their queue.
  + feature:``aws opsworks``: Add AWS OpsWorks support for registering and
    assigning existing Amazon EC2 instances and on-premises servers.
  + feature:``aws opsworks register``: Registers an EC2 instance or machine with
    AWS OpsWorks. Registering a machine using this command will install the
    AWS OpsWorks agent on the target machine and register it with an existing
    OpsWorks stack.
  + bugfix:``aws s3``: Fix issue with expired signatures when retrying
    failed requests
    (`botocore issue 399 <https://github.com/boto/botocore/pull/399>`__)
  + bugfix:``aws cloudformation get-template``: Fix error message when
    template does not exist
    (`issue 1044 <https://github.com/aws/aws-cli/issues/1044>`__)
  + feature:``aws kinesis put-records``: Add support for PutRecord operation. It
    writes multiple data records from a producer into an Amazon Kinesis
    stream in a single call
  + feature:``aws iam get-account-authorization-details``: Add support for
    GetAccountAuthorizationDetails operation. It retrieves information about
    all IAM users, groups, and roles in your account, including their
    relationships to one another and their attached policies.
  + feature:``aws route53 update-hosted-zone-comment``: Add support for updating
    the comment of a hosted zone.
  + bugfix:Timestamp Arguments: Fix issue where certain timestamps were not
    being accepted as valid input
    (`botocore issue 389 <https://github.com/boto/botocore/pull/389>`__)
  + bugfix:``aws s3``: Skip files whose names cannot be properly decoded
    (`issue 1038 <https://github.com/aws/aws-cli/pull/1038>`__)
  + bugfix:``aws kinesis put-record``: Fix issue where ``--data`` argument
    was not being base64 encoded
    (`issue 1033 <https://github.com/aws/aws-cli/issues/1033>`__)
  + bugfix:``aws cloudwatch put-metric-data``: Fix issue where the
    values for ``--statistic-values`` were not being parsed properly
    (`issue 1036 <https://github.com/aws/aws-cli/issues/1036>`__)
  + feature:``aws datapipeline``: Add support for using AWS Data Pipeline
    templates to create pipelines and bind values to parameters in the pipeline
  + feature:``aws elastictranscoder``: Add support for encryption of files in
    Amazon S3
  + bugfix:``aws s3``: Fix issue where requests were not being
    resigned correctly when using Signature Version 4
    (`botocore issue 388 <https://github.com/boto/botocore/pull/388>`__)
  + bugfix:``aws s3``: Fix issue where KMS encrypted objects could not be
    downloaded
    (`issue 1026 <https://github.com/aws/aws-cli/pull/1026>`__)
  + bugfix:``aws s3``: Fix issue where datetime's were not being
    parsed properly when a profile was specified
    (`issue 1020 <https://github.com/aws/aws-cli/issues/1020>`__)
  + bugfix:Assume Role Credential Provider: Fix issue with parsing
    expiry time from assume role credential provider
    (`botocore issue 387 <https://github.com/boto/botocore/pull/387>`__)
  + feature:``aws redshift``: Add support for integration with KMS
  + bugfix:``aws cloudtrail create-subscription``: Set a bucket config
    location constraint on buckets created outside of us-east-1.
    (`issue 1013 <https://github.com/aws/aws-cli/pull/1013>`__)
  + bugfix:``aws deploy push``: Fix s3 multipart uploads
  + bugfix:``aws s3 ls``: Fix return codes for non existing objects
    (`issue 1008 <https://github.com/aws/aws-cli/pull/1008>`__)
  + bugfix:Retrying Signed Requests: Fix issue where requests using
    Signature Version 4 signed with temporary credentials were not
    being retried properly, resulting in auth errors
    (`botocore issue 379 <https://github.com/boto/botocore/pull/379>`__)
  + bugfix:``aws s3api get-bucket-location``: Fix issue where getting the
    bucket location for a bucket in eu-central-1 required specifying
    ``--region eu-central-1``
    (`botocore issue 380 <https://github.com/boto/botocore/pull/380>`__)
  + bugfix:Timestamp Input: Fix regression where timestamps without any timezone
    information were not being handled properly
    (`issue 982 <https://github.com/aws/aws-cli/issues/982>`__)
  + bugfix:Signature Version 4: You can enable Signature Version 4 for Amazon S3
    commands by running ``aws configure set default.s3.signature_version s3v4``
    (`issue 1006 <https://github.com/aws/aws-cli/issues/1006>`__,
    `botocore issue 382 <https://github.com/boto/botocore/pull/382>`__)
  + bugfix:``aws emr``: Fix issue where ``--ssh``, ``--get``, ``--put``
    would not work when the cluster was in a waiting state
    (`issue 1007 <https://github.com/aws/aws-cli/issues/1007>`__)
  + feature:Binary File Input: Add support for reading file contents as binary
    by prepending the filename with ``fileb://``
    (`issue 1010 <https://github.com/aws/aws-cli/pull/1010>`__)
  + bugfix:Streaming Output File: Fix issue when streaming a response to a file
    and an error response is returned
    (`issue 1012 <https://github.com/aws/aws-cli/pull/1012>`__)
  + bugfix:Binary Output: Fix regression where binary output was no longer
    being base64 encoded
    (`issue 1001 <https://github.com/aws/aws-cli/pull/1001>`__,
    `issue 970 <https://github.com/aws/aws-cli/pull/970>`__)
  + feature:``aws lambda``: Add support for Amazon Lambda
  + feature:``aws s3``: Add support for S3 notifications
  + bugfix:``aws configservice get-status``: Fix connecting to endpoint without
    using ssl.
    (`issue 998 <https://github.com/aws/aws-cli/pull/998>`__)
  + bugfix:``aws deploy push``: Fix some python compatibility issues
    (`issue 1000 <https://github.com/aws/aws-cli/pull/1000>`__)
  + feature:``aws deploy``: Adds support for AWS CodeDeploy
  + feature:``aws configservice``: Adds support for AWS Config
  + feature:``aws kms``: Adds support AWS Key Management Service
  + feature:``aws s3api``: Adds support for S3 server-side encryption using
    KMS
  + feature:``aws ec2``: Adds support for EBS encryption using KMS
  + feature:``aws cloudtrail``: Adds support for CloudWatch Logs delivery
  + feature:``aws cloudformation``: Adds support for template summary.
  + feature:AssumeRole Credential Provider: Add support for assuming a role
    by configuring a ``role_arn`` and a ``source_profile`` in the AWS
    config file
    (`issue 991 <https://github.com/aws/aws-cli/pull/991>`__,
    `issue 990 <https://github.com/aws/aws-cli/pull/990>`__)
  + feature:Waiters: Add a ``wait`` subcommand that allows for a command
    to block until an AWS resource reaches a given state
    (`issue 992 <https://github.com/aws/aws-cli/pull/992>`__,
    `issue 985 <https://github.com/aws/aws-cli/pull/985>`__)
  + bugfix:``aws s3``: Fix issue where request was not properly signed
    on retried requests for ``aws s3``
    (`issue 986 <https://github.com/aws/aws-cli/issues/986>`__,
    `botocore issue 375 <https://github.com/boto/botocore/pull/375>`__)
  + bugfix:``aws s3``: Fix issue where ``--exclude`` and ``--include`` were
    not being properly applied when a s3 prefix was provided.
    (`issue 993 <https://github.com/aws/aws-cli/pull/993>`__)
  + feature:``aws cloudfront``: Adds support for wildcard cookie names and
    options caching.
  + feature:``aws route53``: Add further support for private dns and sigv4.
  + feature:``aws cognito-sync``: Add support for push sync.
  + bugfix:Pagination: Only display ``--page-size`` when an operation can be
    paginated
    (`issue 956 <https://github.com/aws/aws-cli/pull/956>`__)
  + feature:``--generate-cli-skeleton``: Generates a JSON skeleton to fill out
    and be used as input to ``--cli-input-json``.
    (`issue 963 <https://github.com/aws/aws-cli/pull/963>`_)
  + feature:``--cli-input-json``: Runs an operation using a global JSON file
    that supplies all of the operation's arguments. This JSON file can
    be generated by ``--generate-cli-skeleton``.
    (`issue 963 <https://github.com/aws/aws-cli/pull/963>`_)
  + feature:``aws s3/s3api``: Show hint about using the correct region when
    the corresponding error occurs
    (`issue 968 <https://github.com/aws/aws-cli/pull/968>`__)
* Thu Oct 23 2014 rschweikert@suse.com
- Update to version 1.5.3  (bnc#902598)
  + feature:aws ec2 describe-volumes: Add support for optional pagination.
  + feature:aws route53domains: Add support for auto-renew domains.
  + feature:aws cognito-identity: Add for Open-ID Connect.
  + feature:aws sts: Add support for Open-ID Connect
  + feature:aws iam: Add support for Open-ID Connect
  + bugfix:aws s3 sync: Fix issue when uploading with
  - -exact-timestamps (issue 964)
  + bugfix:Retry: Fix issue where certain error codes were not being
    retried (botocore issue 361)
  + bugfix:aws emr ssh: Fix issue when using waiter interface to wait on
    the cluster state (issue 954)
  + feature:aws cloudsearch: Add support for advance Japanese language
    processing.
  + feature:aws rds: Add support for gp2 which provides faster access than
    disk-based storage.
  + bugfix:aws s3 mv: Delete multi-part objects when transferring objects
    across regions using --source-region (issue 938)
  + bugfix:aws emr ssh: Fix issue with waiter configuration not being
    found (issue 937)
  + feature:aws dynamodb: Update aws dynamodb command to support storing
    and retrieving documents with full support for document models. New
    data types are fully compatible with the JSON standard and allow you
    to nest document elements within one another.
  + bugfix:aws configure: Fix bug where aws configure was not properly
    writing out to the shared credentials file
  + bugfix:S3 Response Parsing: Fix regression for parsing S3 responses
    containing a status code of 200 with an error response body (botocore
    issue 342)
  + bugfix:Shorthand Error Message: Ensure the error message for shorthand
    parsing always contains the CLI argument name (issue 935)
  + bugfix:Response Parsing: Fix response parsing so that leading and
    trailing spaces are preserved
  + feature:Shared Credentials File: The aws configure and aws configure set
    command now write out all credential variables to the shared
    credentials file ~/.aws/credentials (issue 847)
  + bugfix:aws s3: Write warnings and errors to standard error as opposed to
    standard output. (issue 919)
  + feature:aws s3: Add --only-show-errors option that displays errors and
    warnings but suppresses all other output.
  + feature:aws s3 cp: Added ability to upload local file streams from
    standard input to s3 and download s3 objects as local file streams to
    standard output. (issue 903)
  + feature:aws emr create-cluster: Add support for --emrfs.
  + feature:aws iam: Update aws iam command to latest version.
  + feature:aws cognito-sync: Update aws cognito-sync command to latest
    version.
  + feature:aws opsworks: Update aws opsworks command to latest version.
  + feature:aws elasticbeanstalk: Add support for bundling logs.
  + feature:aws kinesis: Add suport for tagging.
  + feature:Page Size: Add a --page-size option, that controls page size
    when perfoming an operation that uses pagination. (issue 889)
  + bugfix:aws s3: Added support for ignoring and warning about files that
    do not exist, user does not have read permissions, or are special
    files (i.e. sockets, FIFOs, character special devices, and block
    special devices) (issue 881)
  + feature:Parameter Shorthand: Added support for structure(list-scalar,
    scalar) parameter shorthand. (issue 882)
  + bugfix:aws s3: Fix bug when unknown options were passed to aws s3
    commands (issue 886)
  + bugfix:Endpoint URL: Provide a better error message when an invalid
  - -endpoint-url is provided (issue 899)
  + bugfix:aws s3: Fix issue when keys do not get properly url decoded when
    syncing from a bucket that requires pagination to a bucket that
    requires less pagination (issue 909)
  + feature:aws cloudsearchdomain: Added sigv4 support.
  + bugfix:Credentials: Raise an error if an incomplete profile is found
    (issue 690)
  + feature:Signing Requests: Add a --no-sign-request option that, when
    specified, will not sign any requests.
  + bugfix:aws s3: Added -source-region argument to allow transfer between
    non DNS compatible buckets that were located in different regions.
    (issue 872)
  + feature:aws elb: Add support for AWS Elastic Load Balancing tagging
  + feature: aws emr: Move emr out of preview mode.
  + bugfix: aws s3api: Fix serialization of several s3 api commands.
    (issue botocore 193)
  + bugfix: aws s3 sync: Fix issue for unnecessarily resyncing files on
    windows machines. (issue 843)
  + bugfix: aws s3 sync: Fix issue where keys were being decoded twice when
    syncing between buckets. (issue 862)
  + bugfix:aws ec2 describe-network-interface-attribute: Fix issue where
    the model for the aws ec2 describe-network-interface-attribute was
    incorrect (issue 558)
  + bugfix:aws s3: Add option to not follow symlinks via
  - -[no]-follow-symlinks. Note that the default behavior of following
    symlinks is left unchanged. (issue 854, issue 453, issue 781)
  + bugfix:aws route53 change-tags-for-resource: Fix serialization issue
    for aws route53 change-tags-for-resource (botocore issue 328)
  + bugfix:aws ec2 describe-network-interface-attribute: Update parameters
    to add the --attribute argument (botocore issue 327)
  + feature:aws autoscaling: Update command to the latest version
  + feature:aws elasticache: Update command to the latest version
  + feature:aws route53: Update command to the latest version
  + feature:aws route53domains: Add support for Amazon Route53 Domains
  + feature:aws elasticloadbalancing: Update to the latest service model.
  + bugfix:aws swf poll-for-decision-task: Fix issue where the default
    paginated response is missing output response keys (issue botocore 324)
  + bugfix:Connections: Fix issue where connections were hanging when
    network issues occurred issue botocore 325)
  + bugfix:aws s3/s3api: Fix issue where Deprecations were being written
    to stderr in Python 3.4.1 issue botocore 319)
  + feature:aws support: Update aws support command to the latest version
  + feature:aws iam: Update aws iam command to the latest version
  + feature:aws emr: Add --hive-site option to aws emr create-cluster and
    aws emr install-application commands
  + feature:aws s3 sync: Add an --exact-timestamps option to the aws s3
    sync command (issue 824)
  + bugfix:aws ec2 copy-snapshot: Fix bug when spaces in the description
    caused the copy request to fail (issue botocore 321)
  + feature:aws cwlogs: Add support for Amazon CloudWatch Logs
  + feature:aws cognito-sync: Add support for Amazon Cognito Service
  + feature:aws cognito-identity: Add support for Amazon Cognito Identity
    Service
  + feature:aws route53: Update aws route53 command to the latest version
  + feature:aws ec2: Update aws ec2 command to the latest version
  + bugfix:aws s3/s3api: Fix issue where --endpoint-url wasn't being used
    for aws s3/s3api commands (issue 549)
  + bugfix:aws s3 mv: Fix bug where using the aws s3 mv command to move a
    large file onto itself results in the file being deleted (issue 831)
  + bugfix:aws s3: Fix issue where parts in a multipart upload are stil being
    uploaded when a part has failed (issue 834)
  + bugfix:Windows: Fix issue where python.exe is on a path that contains
    spaces (issue 825)
  + feature:aws opsworks: Update the aws opsworks command to the latest version
  + bugfix:Shorthand JSON: Fix bug where shorthand lists with a single
    item (e.g. --arg Param=[item]) were not parsed correctly. (issue 830)
  + bugfix:Text output: Fix bug when rendering only scalars that are
    numbers in text output (issue 829)
  + bugfix:aws cloudsearchdomain: Fix bug where --endpoint-url is required
    even for help subcommands (issue 828)
  + feature:aws cloudsearchdomain: Add support for the Amazon CloudSearch
    Domain command.
  + feature:aws cloudfront: Update the Amazon CloudFront command to the
    latest version
  + feature:aws ses: Add support for delivery notifications
  + bugfix:Region Config: Fix issue for cn-north-1 region (issue botocore 314)
  + bugfix:Amazon EC2 Credential File: Fix regression for parsing EC2
    credential file (issue botocore 315)
  + bugfix:Signature Version 2: Fix timestamp format when calculating
    signature version 2 signatures (issue botocore 308)
  + feature:aws configure: Add support for setting nested attributes
    (issue 817)
  + bugfix:aws s3: Fix issue when uploading large files to newly created
    buckets in a non-standard region (issue 634)
  + feature:aws dynamodb: Add support for a local region for dynamodb
    (aws dynamodb --region local ...) (issue 608)
  + feature:aws elasticbeanstalk: Update aws elasticbeanstalk model to the
    latest version
  + feature:Documentation Examples: Add more documentatoin examples for
    many AWS CLI commands
  + feature:aws emr: Update model to the latest version
  + feature:aws elastictranscoder: Update model to the latest version
  + feature:aws s3api: Add support for server-side encryption with a
    customer-supplied encryption key.
  + feature:aws sns: Support for message attributes.
  + feature:aws redshift: Support for renaming clusters.
  + bugfix:aws s3: Fix bug related to retrying requests when 500 status
    codes are received (issue botocore 302)
  + bugfix:aws s3: Fix when when using S3 in the cn-north-1 region
    (issue botocore 301)
  + bugfix:aws kinesis: Fix pagination bug when using the get-records
    operation (issue botocore 304)
  + bugfix:Python 3.4.1: Add support for python 3.4.1 (issue 800)
  + feature:aws emr: Update preview commands for Amazon Elastic MapReduce
  + bugfix:aws s3: Add filename to error message when we're unable to stat
    local filename (issue 795)
  + bugfix:aws s3api get-bucket-policy: Fix response parsing for the aws
    s3api get-bucket-policy command (issue 678)
  + bugfix:Shared Credentials: Fix bug when specifying profiles that don't
    exist in the CLI config file (issue botocore 294)
  + bugfix:aws s3: Handle Amazon S3 error responses that have a 200 OK
    status code (issue botocore 298)
  + feature:aws sts: Update the aws sts command to the latest version
  + feature:aws cloudsearch: Update the aws cloudsearch command to the
    latest version
  + feature:Shorthand: Add support for surrounding list parameters with []
    chars in shorthand syntax (issue 788)
  + feature:Shared credential file: Add support for the ~/.aws/credentials file
  + feature:aws ec2: Add support for Amazon EBS encryption
  + bugfix:aws s3: Fix issue when --delete and --exclude filters are used
    together (issue 778)
  + feature:aws route53: Update aws route53 to the latest model
  + bugfix:aws emr: Fix issue with aws emr retry logic not being applied
    correctly (botocore issue 285)
  + feature:aws cloudtrail: Add support for eu-west-1, ap-southeast-2
  + bugfix:aws ec2: Fix issue when specifying user data from a file
    containing non-ascii characters (issue 765)
  + bugfix:aws cloudtrail: Fix a bug with python3 when creating a
    subscription (issue 773)
  + bugfix:Shorthand: Fix issue where certain shorthand parameters were
    not parsing to the correct types (issue 776)
  + bugfix:aws cloudformation: Fix issue with parameter casing for the
    NotificationARNs parameter (botocore issue 283)
  + feature:aws cloudformation: Add support for updated API
  + feature:aws sqs: Add support for message attributes
  + bugfix:aws s3api: Fix issue when setting metadata on an S3 object
    (issue 356)
  + feature:aws autoscaling: Add support for launching Dedicated Instances
    in Amazon Virtual Private Cloud
  + feature:aws elasticache: Add support to backup and restore for Redis
    clusters
  + feature:aws dynamodb: Update aws dynamodb command to the latest API
  + bugfix:Output Format: Fix issue with encoding errors when using text
    and table output and redirecting to a pipe or file (issue 742)
  + bugfix:aws s3: Fix issue with sync re-uploading certain files (issue 749)
  + bugfix:Text Output: Fix issue with inconsistent text output based on
    order (issue 751)
  + bugfix:aws datapipeline: Fix issue for aggregating keys into a list
    when calling aws datapipeline get-pipeline-definition (issue 750)
  + bugfix:aws s3: Fix issue when running out of disk space during aws s3
    transfers (issue 739)
  + feature:aws s3 sync: Add --size-only param to the aws s3 sync command
    (issue 472, issue 719)
  + bugfix:aws cloudtrail: Fix issue when using create-subscription
    command (issue botocore 268)
  + feature:aws cloudsearch: Amazon CloudSearch has moved out of preview
    (issue 730)
  + bugfix:aws s3 website: Fix issue where --error-document was being
    ignored in certain cases (issue 714)
  + feature:aws opsworks: Update aws opsworks model to the latest version
  + bugfix:Pagination: Fix issue with --max-items with aws route53, aws iam,
    and aws ses (issue 729)
  + bugfix:aws s3: Fix issue with fips-us-gov-west-1 endpoint (issue
    botocore 265)
  + bugfix:Table Output: Fix issue when displaying unicode characters in
    table output (issue 721)
  + bugfix:aws s3: Fix regression when syncing files with whitespace
    (issue 706, issue 718)
  + bugfix:aws ec2: Fix issue with EC2 model resulting in responses not
    being parsed.
  + feature:aws ec2: Add support for Amazon VPC peering
  + feature:aws redshift: Add support for the latest Amazon Redshift API
  + feature:aws cloudsearch: Add support for the latest Amazon CloudSearch API
  + bugfix:aws cloudformation: Documentation updates
  + bugfix:Argument Parsing: Fix issue when list arguments were not being
    decoded to unicode properly (issue 711)
  + bugfix:Output: Fix issue when invalid output type was provided in a
    config file or environment variable (issue 600)
  + bugfix:aws datapipeline: Fix issue when serializing pipeline definitions
    containing list elements (issue 705)
  + bugfix:aws s3: Fix issue when recursively removing keys containing
    control characters (issue 675)
  + bugfix:aws s3: Honor --no-verify-ssl in high level aws s3 commands
    (issue 696)
  + bugfix:Parameters: Fix issue parsing with CLI parameters of type long
    (issue 693)
  + bugfix:Pagination: Fix issue where --max-items in pagination was always
    assumed to be an integer (issue 689)
  + feature:aws elb: Add support for AccessLog
  + bugfix:Bundled Installer: Allow creation of bundled installer with pip
    1.5 (issue 691)
  + bugfix:aws s3: Fix issue when copying objects using aws s3 cp with key
    names containing + characters (issue #614)
  + bugfix:ec2 create-snapshot: Remove Tags key from output response
    (issue 247)
  + bugfix:aws s3: aws s3 commands should not be requiring regions (issue 681)
  + bugfix:CLI Arguments: Fix issue where unicode command line arguments
    were not being handled correctly (issue 679)
  + bugfix:aws s3: Fix issue where S3 downloads would hang in certain cases
    and could not be interrupted (issue 650, issue 657)
  + bugfix:aws s3: Support missing canned ACLs when using the --acl
    parameter (issue 663)
  + bugfix:aws rds describe-engine-default-parameters: Fix pagination issue
    when calling aws rds describe-engine-default-parameters (issue 607)
  + bugfix:aws cloudtrail: Merge existing SNS topic policy with the
    existing AWS CloudTrail policy instead of overwriting the default
    topic policy
  + bugfix:aws s3: Fix issue where streams were not being rewound when
    encountering 307 redirects with multipart uploads (issue 544)
  + bugfix:aws elb: Fix issue with documentation errors in aws elb help
    (issue 622)
  + bugfix:JSON Parameters: Add a more clear error message when parsing
    invalid JSON parameters (issue 639)
  + bugfix:aws s3api: Properly handle null inputs (issue 637)
  + bugfix:Argument Parsing: Handle files containing JSON with leading
    and trailing spaces (issue 640)
* Thu Feb 27 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #315990)
* Wed Feb 26 2014 rschweikert@suse.com
- update to version 1.2.13
  + feature:aws route53: Update aws route53 command to support string-match
    health checks and the UPSERT action for the aws route53
    change-resource-record-sets command
  + bugfix:Command Completion: Don't show tracebacks on SIGINT (issue 628)
  + bugfix:Docs: Don't duplicate enum values in reference docs (issue 632)
  + bugfix:aws s3: Don't require s3:// prefix (issue 626)
  + feature:aws configure: Add support for configure get and configure set
    command which allow you to set and get configuration values from the AWS
    config file (`issue 602 <https://github.com/aws/aws-cli/issues/602`__)
  + bugfix:aws s3: Fix issue with Amazon S3 downloads on certain OSes
    (`issue 619 <https://github.com/aws/aws-cli/issues/619`__)
  + Add support for the --recursive option in the aws s3 ls command
    (issue 465 <https://github.com/aws/aws-cli/issues/465)
  + Add support for the AWS_CA_BUNDLE environment variable so that users
    can specify an alternate path to a cert bundle (issue 586)
  + Add metadata_service_timeout and metadata_service_num_attempts config
    parameters to control behavior when retrieving credentials using an
    IAM role (issue 597)
  + Retry intermittent aws s3 download failures including socket timeouts
    and content length mismatches (issue 594)
  + Fix response parsing of aws s3api get-bucket-location (issue 345)
  + Fix response parsing of the aws elastictranscoder command (issue 207)
  + Update aws elasticache command to not require certain parameters
* Sat Jan 18 2014 rschweikert@suse.com
- Initial build
